using System;
using System.Collections.Generic;
using System.Text;

namespace Sturm.Util.ApplicationServices.ObjectPooling {
	/// <summary>
	/// Defines the possible behaviours that the GetObject()
	/// method can shows when a pool object isn't (immediately) available.
	/// </summary>
	public enum OutOfObjectsBehaviour {
		/// <summary>
		/// Return null or the default value of the type.
		/// </summary>
		ReturnNull,
		/// <summary>
		/// Wait for a time specified by the Pool.RetryWaitTime property and try again.
		/// A maximum number of tries is specified by the Pool.MaxGetObjectTries
		/// property.
		/// </summary>
		WaitAndRetry,
		/// <summary>
		/// Throw an OutOfObjectsException.
		/// </summary>
		ThrowException,
		/// <summary>
		/// Extend the pool by a default batch as defined by the 
		/// Pool.PoolExtensionBatchSize and Pool.PoolExtensionBatchSizeIsPercent
		/// properties, then try again. A maximum number of tries is specified by 
		/// the Pool.MaxGetObjectTries property.
		/// </summary>
		ExtendPool
	}
}
